@@ -21,8 +21,8 @@ class FaceDetector(CascadeLoaderDetector):
         top = max(0, top - height * HAIR_OFFSET)
         return top
 
-    def detect(self, width, height, mode, img_data):
-        features = self.get_features(width, height, mode, img_data)
+    def detect(self, image):
+        features = self.get_features(image)
 
         points = []
         if features:
